/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  Authors: Iain Holmes <iain@prettypeople.org>
 *
 *  Copyright 2003 Iain Holmes
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of version 2 of the GNU General Public 
 *  License as published by the Free Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __MARLIN_MARKER_VIEW_H__
#define __MARLIN_MARKER_VIEW_H__

#include <gtk/gtkwidget.h>
#include <gtk/gtkadjustment.h>

#include <marlin/marlin-sample.h>
#include <marlin/marlin-marker-model.h>

#ifdef __cplusplus
extern "C" {
#pragma }
#endif

#define MARLIN_MARKER_VIEW_TYPE (marlin_marker_view_get_type ())
#define MARLIN_MARKER_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MARLIN_MARKER_VIEW_TYPE, MarlinMarkerView))
#define MARLIN_MARKER_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MARLIN_MARKER_VIEW_TYPE, MarlinMarkerViewClass))

typedef struct _MarlinMarkerView MarlinMarkerView;
typedef struct _MarlinMarkerViewClass MarlinMarkerViewClass;
typedef struct _MarlinMarkerViewPrivate MarlinMarkerViewPrivate;

struct _MarlinMarkerView {
	GtkWidget parent;

	MarlinMarkerViewPrivate *priv;
};

struct _MarlinMarkerViewClass {
	GtkWidgetClass parent_class;

	void (*set_scroll_adjustments) (MarlinMarkerView *view,
					GtkAdjustment *hadj,
					GtkAdjustment *vadj);
	void (*move_cursor) (MarlinMarkerView *view,
			     guint64 position);
	void (*enter_marker) (MarlinMarkerView *view,
			      MarlinMarker *marker);
	void (*leave_marker) (MarlinMarkerView *view);
};

GType marlin_marker_view_get_type (void);
MarlinMarkerView *marlin_marker_view_new (MarlinMarkerModel *model,
					  MarlinSample *sample);

#ifdef __cplusplus
}
#endif

#endif
