/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  Authors: Iain Holmes <iain@prettypeople.org>
 *
 *  Copyright 2002 Iain Holmes
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of version 2 of the GNU General Public 
 *  License as published by the Free Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __MARLIN_PIPELINE_H__
#define __MARLIN_PIPELINE_H__

#include <glib-object.h>

#include <gst/gst.h>

#define MARLIN_PIPELINE_TYPE (marlin_pipeline_get_type ())
#define MARLIN_PIPELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MARLIN_PIPELINE_TYPE, MarlinPipeline))
#define MARLIN_PIPELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MARLIN_PIPELINE_TYPE, MarlinPipelineClass))
#define IS_MARLIN_PIPELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MARLIN_PIPELINE_TYPE))
#define IS_MARLIN_PIPELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MARLIN_PIPELINE_TYPE))
#define MARLIN_PIPELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MARLIN_PIPELINE_TYPE, MarlinPipelineClass))

typedef struct _MarlinPipeline MarlinPipeline;
typedef struct _MarlinPipelineClass MarlinPipelineClass;
typedef struct _MarlinPipelinePrivate MarlinPipelinePrivate;

struct _MarlinPipeline {
	GObject parent;

	MarlinPipelinePrivate *priv;
};

struct _MarlinPipelineClass {
	GObjectClass parent_class;

	/* Methods */
	int (* get_progress) (MarlinPipeline *pipeline);

	/* Signals */
	void (* shutdown) (MarlinPipeline *pipeline);
	void (* eos) (MarlinPipeline *pipeline);
	void (* position_changed) (MarlinPipeline *pipeline,
				   guint64 position);
};

GType marlin_pipeline_get_type (void);
void marlin_pipeline_position_changed (MarlinPipeline *pipeline,
				       guint64 position);
void marlin_pipeline_add (MarlinPipeline *pipeline,
			  GstElement *element);
void marlin_pipeline_remove (MarlinPipeline *pipeline,
			     GstElement *element);

void marlin_pipeline_set_eos (MarlinPipeline *pipeline);
void marlin_pipeline_set_state (MarlinPipeline *pipeline,
				GstElementState state);
void marlin_pipeline_eos (MarlinPipeline *pipeline);
GstElement *marlin_pipeline_get_element_by_name (MarlinPipeline *pipeline,
						 const char *name);
#endif
