/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  Authors: Iain Holmes <iain@prettypeople.org>
 *
 *  Copyright 2003 Iain Holmes
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of version 2 of the GNU General Public 
 *  License as published by the Free Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __MARLIN_PROGRAM_H__
#define __MARLIN_PROGRAM_H__

#include <glib-object.h>

#include <marlin/marlin-sample.h>

#define MARLIN_PROGRAM_TYPE (marlin_program_get_type ())
#define MARLIN_PROGRAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MARLIN_PROGRAM_TYPE, MarlinProgram))
#define MARLIN_PROGRAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MARLIN_PROGRAM_TYPE, MarlinProgramClass))

typedef struct _MarlinProgramPrivate MarlinProgramPrivate;
typedef struct _MarlinProgram {
	GObject parent;

	MarlinProgramPrivate *priv;
} MarlinProgram;

typedef struct _MarlinProgramClass {
	GObjectClass parent_class;

	void (*new_window) (MarlinProgram *program,
			    GObject *window_object);
	void (*clipboard_changed) (MarlinProgram *program);
} MarlinProgramClass;

GType marlin_program_get_type (void);
MarlinProgram *marlin_program_get_default (void);
void marlin_program_destroy_default (void);
GObject *marlin_program_get_clipboard (MarlinProgram *program);
void marlin_program_set_clipboard (MarlinProgram *program,
				   GObject *clipboard_object,
				   const char *src);
const char *marlin_program_get_clip_source (MarlinProgram *program);

void marlin_program_play_pipeline (MarlinProgram *program);
void marlin_program_stop_pipeline (MarlinProgram *program);
#endif
