/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  Authors: Iain Holmes <iain@prettypeople.org>
 *
 *  Copyright 2002 Iain Holmes
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of version 2 of the GNU General Public 
 *  License as published by the Free Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __HAVE_MARLIN_SAMPLE_ELEMENT_H__
#define __HAVE_MARLIN_SAMPLE_ELEMENT_H__

#include <gst/gst.h>
#include <marlin/marlin-sample.h>
#include <marlin/marlin-marker-model.h>

#define MARLIN_SAMPLE_ELEMENT_SINK_TYPE (marlin_sample_element_sink_get_type ())
#define MARLIN_SAMPLE_ELEMENT_SINK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MARLIN_SAMPLE_ELEMENT_SINK_TYPE, MarlinSampleElementSink))
#define MARLIN_SAMPLE_ELEMENT_SINK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MARLIN_SAMPLE_ELEMENT_SINK_TYPE, MarlinSampleElementSinkClass))

typedef struct _MarlinSampleElementSink MarlinSampleElementSink;
typedef struct _MarlinSampleElementSinkClass MarlinSampleElementSinkClass;

struct _MarlinSampleElementSink {
	GstElement element;

	GstPad *sinkpad;
	MarlinSample *sample;

	int numsinkpads;
	int buffer_frames;
	guint rate;
	GList *input_channels;

	gboolean no_space; /* Have we run out of space */
	GError *no_space_error;
	guint64 no_space_frames;
	guint64 frame_count;

	guint64 insert_position;
};

struct _MarlinSampleElementSinkClass {
	GstElementClass parent_class;
};

GType marlin_sample_element_sink_get_type (void);
MarlinSampleElementSink *marlin_sample_element_sink_new (MarlinSample *sample);

/* ---------------- Src element--------------- */
#define MARLIN_SAMPLE_ELEMENT_SRC_TYPE (marlin_sample_element_src_get_type ())
#define MARLIN_SAMPLE_ELEMENT_SRC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MARLIN_SAMPLE_ELEMENT_SRC_TYPE, MarlinSampleElementSrc))
#define MARLIN_SAMPLE_ELEMENT_SRC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MARLIN_SAMPLE_ELEMENT_SRC_TYPE, MarlinSampleElementSrcClass))

typedef struct _MarlinSampleElementSrc MarlinSampleElementSrc;
typedef struct _MarlinSampleElementSrcClass MarlinSampleElementSrcClass;

struct _MarlinSampleElementSrc {
	GstElement element;

	MarlinSample *sample;
	gulong notify_id;
	gulong frames_changed_id;
	
	guint block_size;
	guint64 num_frames;
	guint sample_rate;

	guint64 start; /* For segment playing */
	guint64 end;
	gboolean segment_loop;
	
	guint numsrcpads;
	GList *srcpads;

	gboolean need_taglist; /* Have we sent the taglist down the pipeline
				  yet? */
	gboolean send_new_media;
	gboolean sent_first;
	gboolean need_new_media;
	MarlinMarkerModel *model;
	MarlinMarker *new_media_marker;
	GList *markers;

	gboolean loop;
};

struct _MarlinSampleElementSrcClass {
	GstElementClass parent_class;
};

GType marlin_sample_element_src_get_type (void);
MarlinSampleElementSrc *marlin_sample_element_src_new (MarlinSample *sample);

gboolean marlin_sample_element_src_seek_range (MarlinSampleElementSrc *src,
					       GstSeekType type,
					       gint64 start,
					       gint64 finish);
gboolean marlin_sample_element_src_seek (MarlinSampleElementSrc *src,
					 GstSeekType type,
					 gint64 offset);


#endif
