/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 *  Authors: Iain Holmes <iain@prettypeople.org>
 *
 *  Copyright 2002 - 2004 Iain Holmes
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef __MARLIN_UNDOABLE_H__
#define __MARLIN_UNDOABLE_H__

#include <glib.h>
#include <glib-object.h>

typedef void (*MarlinUndoableFunc) (gpointer closure);

typedef struct _MarlinUndoable {
	/* The functions that will undo/redo the action if they are passed
	 * the data packet that is stored in closure */
	MarlinUndoableFunc undo; 
	MarlinUndoableFunc redo; 
	MarlinUndoableFunc destroy;

	gpointer closure; /* This is enough data for the undo/redo functions
			     to perform their actions */
} MarlinUndoable;

MarlinUndoable *marlin_undoable_new (MarlinUndoableFunc undo,
				     MarlinUndoableFunc redo,
				     MarlinUndoableFunc destroy,
				     gpointer closure);
void marlin_undoable_free (MarlinUndoable *undoable);
void marlin_undoable_undo (MarlinUndoable *undoable);
void marlin_undoable_redo (MarlinUndoable *undoable);

#endif
